#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import careplan
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class CarePlanTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("CarePlan", js["resourceType"])
        return careplan.CarePlan(js)
    
    def testCarePlan1(self):
        inst = self.instantiate_from("careplan-example-f001-heart.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan1(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan1(inst2)
    
    def implCarePlan1(self, inst):
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].code), force_bytes("procedure"))
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].code), force_bytes("64915003"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].display), force_bytes("Operation on heart"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertTrue(inst.activity[0].detail.prohibited)
        self.assertEqual(force_bytes(inst.activity[0].detail.scheduledString), force_bytes("2011-06-27T09:30:10+01:00"))
        self.assertEqual(force_bytes(inst.activity[0].detail.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("careteam"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f001"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://www.bmc.nl/zorgportal/identifiers/careplans"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("CP2903"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(inst.period.end.date, FHIRDate("2011-06-27").date)
        self.assertEqual(inst.period.end.as_json(), "2011-06-27")
        self.assertEqual(inst.period.start.date, FHIRDate("2011-06-26").date)
        self.assertEqual(inst.period.start.as_json(), "2011-06-26")
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testCarePlan2(self):
        inst = self.instantiate_from("careplan-example-GPVisit.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan2(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan2(inst2)
    
    def implCarePlan2(self, inst):
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].code), force_bytes("encounter"))
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].code), force_bytes("nursecon"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].system), force_bytes("http://example.org/local"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.text), force_bytes("Nurse Consultation"))
        self.assertFalse(inst.activity[0].detail.prohibited)
        self.assertEqual(inst.activity[0].detail.scheduledPeriod.end.date, FHIRDate("2013-01-01T10:50:00+00:00").date)
        self.assertEqual(inst.activity[0].detail.scheduledPeriod.end.as_json(), "2013-01-01T10:50:00+00:00")
        self.assertEqual(inst.activity[0].detail.scheduledPeriod.start.date, FHIRDate("2013-01-01T10:38:00+00:00").date)
        self.assertEqual(inst.activity[0].detail.scheduledPeriod.start.as_json(), "2013-01-01T10:38:00+00:00")
        self.assertEqual(force_bytes(inst.activity[0].detail.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.activity[1].detail.category.coding[0].code), force_bytes("encounter"))
        self.assertEqual(force_bytes(inst.activity[1].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.coding[0].code), force_bytes("doccon"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.coding[0].system), force_bytes("http://example.org/local"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.text), force_bytes("Doctor Consultation"))
        self.assertFalse(inst.activity[1].detail.prohibited)
        self.assertEqual(force_bytes(inst.activity[1].detail.status), force_bytes("scheduled"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("p1"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("careteam"))
        self.assertEqual(force_bytes(inst.contained[2].id), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.id), force_bytes("gpvisit"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(inst.period.start.date, FHIRDate("2013-01-01T10:30:00+00:00").date)
        self.assertEqual(inst.period.start.as_json(), "2013-01-01T10:30:00+00:00")
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))
    
    def testCarePlan3(self):
        inst = self.instantiate_from("careplan-example-f202-malignancy.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan3(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan3(inst2)
    
    def implCarePlan3(self, inst):
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].code), force_bytes("procedure"))
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].code), force_bytes("367336001"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].display), force_bytes("Chemotherapy"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertFalse(inst.activity[0].detail.prohibited)
        self.assertEqual(force_bytes(inst.activity[0].detail.status), force_bytes("in-progress"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("doce"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("cisp"))
        self.assertEqual(force_bytes(inst.contained[2].id), force_bytes("fluo"))
        self.assertEqual(force_bytes(inst.contained[3].id), force_bytes("tpf"))
        self.assertEqual(force_bytes(inst.contained[4].id), force_bytes("careteam"))
        self.assertEqual(force_bytes(inst.contained[5].id), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f202"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testCarePlan4(self):
        inst = self.instantiate_from("careplan-example-obesity-narrative.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan4(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan4(inst2)
    
    def implCarePlan4(self, inst):
        self.assertEqual(force_bytes(inst.id), force_bytes("obesity-narrative"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))
    
    def testCarePlan5(self):
        inst = self.instantiate_from("careplan-example-integrated.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan5(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan5(inst2)
    
    def implCarePlan5(self, inst):
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[0].detail.description), force_bytes("Eve will review photos of high and low density foods and share with her parents"))
        self.assertEqual(force_bytes(inst.activity[0].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[0].detail.extension[0].valueDate.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[0].detail.extension[0].valueDate.as_json(), "2012-09-10")
        self.assertFalse(inst.activity[0].detail.prohibited)
        self.assertEqual(inst.activity[0].detail.scheduledPeriod.start.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[0].detail.scheduledPeriod.start.as_json(), "2012-09-10")
        self.assertEqual(force_bytes(inst.activity[0].detail.status), force_bytes("not-started"))
        self.assertEqual(force_bytes(inst.activity[0].progress[0].text), force_bytes("Eve eats one meal a day with her parents"))
        self.assertEqual(inst.activity[0].progress[0].time.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[0].progress[0].time.as_json(), "2012-09-10")
        self.assertEqual(force_bytes(inst.activity[1].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[1].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[1].detail.description), force_bytes("Eve will ask her dad to asist her to put the head of her bed on blocks"))
        self.assertEqual(force_bytes(inst.activity[1].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[1].detail.extension[0].valueDate.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[1].detail.extension[0].valueDate.as_json(), "2012-09-10")
        self.assertFalse(inst.activity[1].detail.prohibited)
        self.assertEqual(inst.activity[1].detail.scheduledPeriod.start.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[1].detail.scheduledPeriod.start.as_json(), "2012-09-10")
        self.assertEqual(force_bytes(inst.activity[1].detail.status), force_bytes("not-started"))
        self.assertEqual(force_bytes(inst.activity[1].progress[0].text), force_bytes("Eve will sleep in her bed more often than the couch"))
        self.assertEqual(inst.activity[1].progress[0].time.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[1].progress[0].time.as_json(), "2012-09-10")
        self.assertEqual(force_bytes(inst.activity[2].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[2].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[2].detail.description), force_bytes("Eve will reduce her intake of coffee and chocolate"))
        self.assertEqual(force_bytes(inst.activity[2].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[2].detail.extension[0].valueDate.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[2].detail.extension[0].valueDate.as_json(), "2012-09-10")
        self.assertFalse(inst.activity[2].detail.prohibited)
        self.assertEqual(inst.activity[2].detail.scheduledPeriod.start.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[2].detail.scheduledPeriod.start.as_json(), "2012-09-10")
        self.assertEqual(force_bytes(inst.activity[2].detail.status), force_bytes("in-progress"))
        self.assertEqual(force_bytes(inst.activity[3].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[3].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[3].detail.description), force_bytes("Eve will walk her friend's dog up and down a big hill 15-30 minutes 3 days a week"))
        self.assertEqual(force_bytes(inst.activity[3].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[3].detail.extension[0].valueDate.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[3].detail.extension[0].valueDate.as_json(), "2012-09-10")
        self.assertFalse(inst.activity[3].detail.prohibited)
        self.assertEqual(inst.activity[3].detail.scheduledPeriod.start.date, FHIRDate("2012-08-27").date)
        self.assertEqual(inst.activity[3].detail.scheduledPeriod.start.as_json(), "2012-08-27")
        self.assertEqual(force_bytes(inst.activity[3].detail.status), force_bytes("in-progress"))
        self.assertEqual(force_bytes(inst.activity[3].progress[0].text), force_bytes("Eve would like to try for 5 days a week."))
        self.assertEqual(inst.activity[3].progress[0].time.date, FHIRDate("2012-08-27").date)
        self.assertEqual(inst.activity[3].progress[0].time.as_json(), "2012-08-27")
        self.assertEqual(force_bytes(inst.activity[3].progress[1].text), force_bytes("Eve is still walking the dogs."))
        self.assertEqual(inst.activity[3].progress[1].time.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[3].progress[1].time.as_json(), "2012-09-10")
        self.assertEqual(force_bytes(inst.activity[4].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[4].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[4].detail.description), force_bytes("Eve will walk 3 blocks to her parents house twice a week"))
        self.assertEqual(force_bytes(inst.activity[4].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[4].detail.extension[0].valueDate.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[4].detail.extension[0].valueDate.as_json(), "2012-09-10")
        self.assertFalse(inst.activity[4].detail.prohibited)
        self.assertEqual(inst.activity[4].detail.scheduledPeriod.start.date, FHIRDate("2012-07-23").date)
        self.assertEqual(inst.activity[4].detail.scheduledPeriod.start.as_json(), "2012-07-23")
        self.assertEqual(force_bytes(inst.activity[4].detail.status), force_bytes("in-progress"))
        self.assertEqual(force_bytes(inst.activity[4].progress[0].text), force_bytes("Eve walked 4 times the last week."))
        self.assertEqual(inst.activity[4].progress[0].time.date, FHIRDate("2012-08-13").date)
        self.assertEqual(inst.activity[4].progress[0].time.as_json(), "2012-08-13")
        self.assertEqual(force_bytes(inst.activity[4].progress[1].text), force_bytes("Eve did not walk to her parents the last week, but has plans to start again"))
        self.assertEqual(inst.activity[4].progress[1].time.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[4].progress[1].time.as_json(), "2012-09-10")
        self.assertEqual(force_bytes(inst.activity[5].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[5].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[5].detail.description), force_bytes("Eve will us a calendar to check off after medications are taken"))
        self.assertEqual(force_bytes(inst.activity[5].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[5].detail.extension[0].valueDate.date, FHIRDate("2012-08-13").date)
        self.assertEqual(inst.activity[5].detail.extension[0].valueDate.as_json(), "2012-08-13")
        self.assertFalse(inst.activity[5].detail.prohibited)
        self.assertEqual(inst.activity[5].detail.scheduledPeriod.start.date, FHIRDate("2012-07-23").date)
        self.assertEqual(inst.activity[5].detail.scheduledPeriod.start.as_json(), "2012-07-23")
        self.assertEqual(force_bytes(inst.activity[5].detail.status), force_bytes("in-progress"))
        self.assertEqual(force_bytes(inst.activity[6].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[6].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[6].detail.description), force_bytes("Eve will use her lights MWF after her shower for 3 minutes"))
        self.assertEqual(force_bytes(inst.activity[6].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[6].detail.extension[0].valueDate.date, FHIRDate("2012-08-27").date)
        self.assertEqual(inst.activity[6].detail.extension[0].valueDate.as_json(), "2012-08-27")
        self.assertFalse(inst.activity[6].detail.prohibited)
        self.assertEqual(inst.activity[6].detail.scheduledPeriod.start.date, FHIRDate("2012-07-23").date)
        self.assertEqual(inst.activity[6].detail.scheduledPeriod.start.as_json(), "2012-07-23")
        self.assertEqual(force_bytes(inst.activity[6].detail.status), force_bytes("in-progress"))
        self.assertEqual(force_bytes(inst.activity[6].progress[0].text), force_bytes("After restarting the vinegar soaks the psoriasis is improved and Eve plans to treat the remainder with light treatments.  She plans to start this week."))
        self.assertEqual(inst.activity[6].progress[0].time.date, FHIRDate("2012-08-13").date)
        self.assertEqual(inst.activity[6].progress[0].time.as_json(), "2012-08-13")
        self.assertEqual(force_bytes(inst.activity[6].progress[1].text), force_bytes("Since her skin is improved Eve has not been using the light treatment as often, maybe once a week.  She would like to increase to 3 times a week again"))
        self.assertEqual(inst.activity[6].progress[1].time.date, FHIRDate("2012-08-27").date)
        self.assertEqual(inst.activity[6].progress[1].time.as_json(), "2012-08-27")
        self.assertEqual(force_bytes(inst.activity[7].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[7].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[7].detail.description), force_bytes("Eve will use a calendar of a chart to help her remember when to take her medications"))
        self.assertEqual(force_bytes(inst.activity[7].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[7].detail.extension[0].valueDate.date, FHIRDate("2012-09-10").date)
        self.assertEqual(inst.activity[7].detail.extension[0].valueDate.as_json(), "2012-09-10")
        self.assertFalse(inst.activity[7].detail.prohibited)
        self.assertEqual(inst.activity[7].detail.scheduledPeriod.start.date, FHIRDate("2012-07-10").date)
        self.assertEqual(inst.activity[7].detail.scheduledPeriod.start.as_json(), "2012-07-10")
        self.assertEqual(force_bytes(inst.activity[7].detail.status), force_bytes("in-progress"))
        self.assertEqual(force_bytes(inst.activity[7].progress[0].text), force_bytes("Eve created a chart as a reminer to take the medications that do not fit in her pill box"))
        self.assertEqual(inst.activity[7].progress[0].time.date, FHIRDate("2012-07-23").date)
        self.assertEqual(inst.activity[7].progress[0].time.as_json(), "2012-07-23")
        self.assertEqual(force_bytes(inst.activity[8].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[8].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[8].detail.description), force_bytes("Eve will start using stretch bands and one step 2 days a week Mon/Wed 6-7am and maybe Friday afternoon"))
        self.assertEqual(force_bytes(inst.activity[8].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[8].detail.extension[0].valueDate.date, FHIRDate("2012-08-23").date)
        self.assertEqual(inst.activity[8].detail.extension[0].valueDate.as_json(), "2012-08-23")
        self.assertFalse(inst.activity[8].detail.prohibited)
        self.assertEqual(inst.activity[8].detail.scheduledPeriod.start.date, FHIRDate("2012-07-23").date)
        self.assertEqual(inst.activity[8].detail.scheduledPeriod.start.as_json(), "2012-07-23")
        self.assertEqual(force_bytes(inst.activity[8].detail.status), force_bytes("on-hold"))
        self.assertEqual(force_bytes(inst.activity[8].progress[0].text), force_bytes("Will be able to esume exercise."))
        self.assertEqual(inst.activity[8].progress[0].time.date, FHIRDate("2012-07-30").date)
        self.assertEqual(inst.activity[8].progress[0].time.as_json(), "2012-07-30")
        self.assertEqual(force_bytes(inst.activity[8].progress[1].text), force_bytes("Eve prefers to focus on walking at this time"))
        self.assertEqual(inst.activity[8].progress[1].time.date, FHIRDate("2012-08-13").date)
        self.assertEqual(inst.activity[8].progress[1].time.as_json(), "2012-08-13")
        self.assertEqual(force_bytes(inst.activity[9].detail.category.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.activity[9].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[9].detail.description), force_bytes("Eve will match a printed medication worksheet with the medication bottles at home"))
        self.assertEqual(force_bytes(inst.activity[9].detail.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/RevisionDate"))
        self.assertEqual(inst.activity[9].detail.extension[0].valueDate.date, FHIRDate("2012-07-23").date)
        self.assertEqual(inst.activity[9].detail.extension[0].valueDate.as_json(), "2012-07-23")
        self.assertFalse(inst.activity[9].detail.prohibited)
        self.assertEqual(inst.activity[9].detail.scheduledPeriod.start.date, FHIRDate("2012-07-10").date)
        self.assertEqual(inst.activity[9].detail.scheduledPeriod.start.as_json(), "2012-07-10")
        self.assertEqual(force_bytes(inst.activity[9].detail.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("p1"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("p2"))
        self.assertEqual(force_bytes(inst.contained[2].id), force_bytes("p3"))
        self.assertEqual(force_bytes(inst.contained[3].id), force_bytes("g1"))
        self.assertEqual(force_bytes(inst.contained[4].id), force_bytes("g2"))
        self.assertEqual(force_bytes(inst.contained[5].id), force_bytes("g3"))
        self.assertEqual(force_bytes(inst.contained[6].id), force_bytes("g4"))
        self.assertEqual(force_bytes(inst.contained[7].id), force_bytes("g5"))
        self.assertEqual(force_bytes(inst.id), force_bytes("integrate"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(force_bytes(inst.note[0].text), force_bytes("Patient family is not ready to commit to goal setting at this time.  Goal setting will be addressed in the future"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testCarePlan6(self):
        inst = self.instantiate_from("careplan-example-f203-sepsis.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan6(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan6(inst2)
    
    def implCarePlan6(self, inst):
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].code), force_bytes("observation"))
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].code), force_bytes("241541005"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].display), force_bytes("High resolution computed tomography of lungs"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertFalse(inst.activity[0].detail.prohibited)
        self.assertEqual(force_bytes(inst.activity[0].detail.status), force_bytes("not-started"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("careteam"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f203"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(inst.period.end.date, FHIRDate("2013-04-21").date)
        self.assertEqual(inst.period.end.as_json(), "2013-04-21")
        self.assertEqual(inst.period.start.date, FHIRDate("2013-04-14").date)
        self.assertEqual(inst.period.start.as_json(), "2013-04-14")
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testCarePlan7(self):
        inst = self.instantiate_from("careplan-example-f201-renal.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan7(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan7(inst2)
    
    def implCarePlan7(self, inst):
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].code), force_bytes("diet"))
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].code), force_bytes("284093001"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].display), force_bytes("Potassium supplementation"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.activity[0].detail.dailyAmount.code), force_bytes("258718000"))
        self.assertEqual(force_bytes(inst.activity[0].detail.dailyAmount.system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.activity[0].detail.dailyAmount.unit), force_bytes("mmol"))
        self.assertEqual(inst.activity[0].detail.dailyAmount.value, 80)
        self.assertFalse(inst.activity[0].detail.prohibited)
        self.assertEqual(force_bytes(inst.activity[0].detail.scheduledString), force_bytes("daily"))
        self.assertEqual(force_bytes(inst.activity[0].detail.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.activity[1].detail.category.coding[0].code), force_bytes("observation"))
        self.assertEqual(force_bytes(inst.activity[1].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.coding[0].code), force_bytes("306005"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.coding[0].display), force_bytes("Echography of kidney"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertFalse(inst.activity[1].detail.prohibited)
        self.assertEqual(force_bytes(inst.activity[1].detail.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("careteam"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f201"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("proposal"))
        self.assertEqual(inst.period.end.date, FHIRDate("2013-03-13").date)
        self.assertEqual(inst.period.end.as_json(), "2013-03-13")
        self.assertEqual(inst.period.start.date, FHIRDate("2013-03-11").date)
        self.assertEqual(inst.period.start.as_json(), "2013-03-11")
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testCarePlan8(self):
        inst = self.instantiate_from("careplan-example-f002-lung.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan8(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan8(inst2)
    
    def implCarePlan8(self, inst):
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].code), force_bytes("procedure"))
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].code), force_bytes("359615001"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].display), force_bytes("Partial lobectomy of lung"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertTrue(inst.activity[0].detail.prohibited)
        self.assertEqual(force_bytes(inst.activity[0].detail.scheduledString), force_bytes("2011-07-07T09:30:10+01:00"))
        self.assertEqual(force_bytes(inst.activity[0].detail.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("careteam"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f002"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://www.bmc.nl/zorgportal/identifiers/careplans"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("CP2934"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(inst.period.end.date, FHIRDate("2013-07-07").date)
        self.assertEqual(inst.period.end.as_json(), "2013-07-07")
        self.assertEqual(inst.period.start.date, FHIRDate("2011-07-06").date)
        self.assertEqual(inst.period.start.as_json(), "2011-07-06")
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testCarePlan9(self):
        inst = self.instantiate_from("careplan-example-f003-pharynx.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan9(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan9(inst2)
    
    def implCarePlan9(self, inst):
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].code), force_bytes("procedure"))
        self.assertEqual(force_bytes(inst.activity[0].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].code), force_bytes("172960003"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].display), force_bytes("Incision of retropharyngeal abscess"))
        self.assertEqual(force_bytes(inst.activity[0].detail.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertTrue(inst.activity[0].detail.prohibited)
        self.assertEqual(force_bytes(inst.activity[0].detail.scheduledString), force_bytes("2011-06-27T09:30:10+01:00"))
        self.assertEqual(force_bytes(inst.activity[0].detail.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("careteam"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f003"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://www.bmc.nl/zorgportal/identifiers/careplans"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("CP3953"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(inst.period.end.date, FHIRDate("2013-03-08T09:30:10+01:00").date)
        self.assertEqual(inst.period.end.as_json(), "2013-03-08T09:30:10+01:00")
        self.assertEqual(inst.period.start.date, FHIRDate("2013-03-08T09:00:10+01:00").date)
        self.assertEqual(inst.period.start.as_json(), "2013-03-08T09:00:10+01:00")
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testCarePlan10(self):
        inst = self.instantiate_from("careplan-example-pregnancy.json")
        self.assertIsNotNone(inst, "Must have instantiated a CarePlan instance")
        self.implCarePlan10(inst)
        
        js = inst.as_json()
        self.assertEqual("CarePlan", js["resourceType"])
        inst2 = careplan.CarePlan(js)
        self.implCarePlan10(inst2)
    
    def implCarePlan10(self, inst):
        self.assertEqual(force_bytes(inst.activity[1].detail.category.coding[0].code), force_bytes("encounter"))
        self.assertEqual(force_bytes(inst.activity[1].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.coding[0].code), force_bytes("1an"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.coding[0].system), force_bytes("http://example.org/mySystem"))
        self.assertEqual(force_bytes(inst.activity[1].detail.code.text), force_bytes("First Antenatal encounter"))
        self.assertEqual(force_bytes(inst.activity[1].detail.description), force_bytes("The first antenatal encounter. This is where a detailed physical examination is performed.             and the pregnanacy discussed with the mother-to-be."))
        self.assertFalse(inst.activity[1].detail.prohibited)
        self.assertEqual(inst.activity[1].detail.scheduledTiming.repeat.boundsPeriod.end.date, FHIRDate("2013-02-28").date)
        self.assertEqual(inst.activity[1].detail.scheduledTiming.repeat.boundsPeriod.end.as_json(), "2013-02-28")
        self.assertEqual(inst.activity[1].detail.scheduledTiming.repeat.boundsPeriod.start.date, FHIRDate("2013-02-14").date)
        self.assertEqual(inst.activity[1].detail.scheduledTiming.repeat.boundsPeriod.start.as_json(), "2013-02-14")
        self.assertEqual(force_bytes(inst.activity[1].detail.status), force_bytes("scheduled"))
        self.assertEqual(force_bytes(inst.activity[1].extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/careplan#andetails"))
        self.assertEqual(force_bytes(inst.activity[1].extension[0].valueUri), force_bytes("http://orionhealth.com/fhir/careplan/1andetails"))
        self.assertEqual(force_bytes(inst.activity[2].detail.category.coding[0].code), force_bytes("encounter"))
        self.assertEqual(force_bytes(inst.activity[2].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[2].detail.code.coding[0].code), force_bytes("an"))
        self.assertEqual(force_bytes(inst.activity[2].detail.code.coding[0].system), force_bytes("http://example.org/mySystem"))
        self.assertEqual(force_bytes(inst.activity[2].detail.code.text), force_bytes("Follow-up Antenatal encounter"))
        self.assertEqual(force_bytes(inst.activity[2].detail.description), force_bytes("The second antenatal encounter. Discuss any issues that arose from the first antenatal encounter"))
        self.assertFalse(inst.activity[2].detail.prohibited)
        self.assertEqual(inst.activity[2].detail.scheduledTiming.repeat.boundsPeriod.end.date, FHIRDate("2013-03-14").date)
        self.assertEqual(inst.activity[2].detail.scheduledTiming.repeat.boundsPeriod.end.as_json(), "2013-03-14")
        self.assertEqual(inst.activity[2].detail.scheduledTiming.repeat.boundsPeriod.start.date, FHIRDate("2013-03-01").date)
        self.assertEqual(inst.activity[2].detail.scheduledTiming.repeat.boundsPeriod.start.as_json(), "2013-03-01")
        self.assertEqual(force_bytes(inst.activity[2].detail.status), force_bytes("not-started"))
        self.assertEqual(force_bytes(inst.activity[3].detail.category.coding[0].code), force_bytes("encounter"))
        self.assertEqual(force_bytes(inst.activity[3].detail.category.coding[0].system), force_bytes("http://hl7.org/fhir/care-plan-activity-category"))
        self.assertEqual(force_bytes(inst.activity[3].detail.code.coding[0].code), force_bytes("del"))
        self.assertEqual(force_bytes(inst.activity[3].detail.code.coding[0].system), force_bytes("http://example.org/mySystem"))
        self.assertEqual(force_bytes(inst.activity[3].detail.code.text), force_bytes("Delivery"))
        self.assertEqual(force_bytes(inst.activity[3].detail.description), force_bytes("The delivery."))
        self.assertFalse(inst.activity[3].detail.prohibited)
        self.assertEqual(inst.activity[3].detail.scheduledTiming.repeat.boundsPeriod.end.date, FHIRDate("2013-09-14").date)
        self.assertEqual(inst.activity[3].detail.scheduledTiming.repeat.boundsPeriod.end.as_json(), "2013-09-14")
        self.assertEqual(inst.activity[3].detail.scheduledTiming.repeat.boundsPeriod.start.date, FHIRDate("2013-09-01").date)
        self.assertEqual(inst.activity[3].detail.scheduledTiming.repeat.boundsPeriod.start.as_json(), "2013-09-01")
        self.assertEqual(force_bytes(inst.activity[3].detail.status), force_bytes("not-started"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("p1"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("pr1"))
        self.assertEqual(force_bytes(inst.contained[2].id), force_bytes("pr2"))
        self.assertEqual(force_bytes(inst.contained[3].id), force_bytes("careteam"))
        self.assertEqual(force_bytes(inst.contained[4].id), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/careplan#lmp"))
        self.assertEqual(inst.extension[0].valueDateTime.date, FHIRDate("2013-01-01").date)
        self.assertEqual(inst.extension[0].valueDateTime.as_json(), "2013-01-01")
        self.assertEqual(force_bytes(inst.id), force_bytes("preg"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(inst.period.end.date, FHIRDate("2013-10-01").date)
        self.assertEqual(inst.period.end.as_json(), "2013-10-01")
        self.assertEqual(inst.period.start.date, FHIRDate("2013-01-01").date)
        self.assertEqual(inst.period.start.as_json(), "2013-01-01")
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import servicedefinition
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class ServiceDefinitionTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("ServiceDefinition", js["resourceType"])
        return servicedefinition.ServiceDefinition(js)
    
    def testServiceDefinition1(self):
        inst = self.instantiate_from("servicedefinition-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a ServiceDefinition instance")
        self.implServiceDefinition1(inst)
        
        js = inst.as_json()
        self.assertEqual("ServiceDefinition", js["resourceType"])
        inst2 = servicedefinition.ServiceDefinition(js)
        self.implServiceDefinition1(inst2)
    
    def implServiceDefinition1(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2015-07-22").date)
        self.assertEqual(inst.date.as_json(), "2015-07-22")
        self.assertEqual(force_bytes(inst.description), force_bytes("Guideline appropriate ordering is used to assess appropriateness of an order given a patient, a proposed order, and a set of clinical indications."))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("guildeline-appropriate-ordering"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Guideline Appropriate Ordering Module"))
        self.assertEqual(force_bytes(inst.topic[0].text), force_bytes("Guideline Appropriate Ordering"))
        self.assertEqual(force_bytes(inst.topic[1].text), force_bytes("Appropriate Use Criteria"))
        self.assertEqual(force_bytes(inst.version), force_bytes("1.0.0"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import schedule
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class ScheduleTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Schedule", js["resourceType"])
        return schedule.Schedule(js)
    
    def testSchedule1(self):
        inst = self.instantiate_from("schedule-provider-location1-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Schedule instance")
        self.implSchedule1(inst)
        
        js = inst.as_json()
        self.assertEqual("Schedule", js["resourceType"])
        inst2 = schedule.Schedule(js)
        self.implSchedule1(inst2)
    
    def implSchedule1(self, inst):
        self.assertTrue(inst.active)
        self.assertEqual(force_bytes(inst.comment), force_bytes("The slots attached to this schedule are for genetic counselling in the USS Enterprise-D Sickbay."))
        self.assertEqual(force_bytes(inst.id), force_bytes("exampleloc1"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://example.org/scheduleid"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("usual"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("46"))
        self.assertEqual(inst.planningHorizon.end.date, FHIRDate("2017-12-25T09:30:00Z").date)
        self.assertEqual(inst.planningHorizon.end.as_json(), "2017-12-25T09:30:00Z")
        self.assertEqual(inst.planningHorizon.start.date, FHIRDate("2017-12-25T09:15:00Z").date)
        self.assertEqual(inst.planningHorizon.start.as_json(), "2017-12-25T09:15:00Z")
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].code), force_bytes("17"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].display), force_bytes("General Practice"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].code), force_bytes("75"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].display), force_bytes("Genetic Counselling"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].code), force_bytes("394580004"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].display), force_bytes("Clinical genetics"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testSchedule2(self):
        inst = self.instantiate_from("schedule-provider-location2-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Schedule instance")
        self.implSchedule2(inst)
        
        js = inst.as_json()
        self.assertEqual("Schedule", js["resourceType"])
        inst2 = schedule.Schedule(js)
        self.implSchedule2(inst2)
    
    def implSchedule2(self, inst):
        self.assertTrue(inst.active)
        self.assertEqual(force_bytes(inst.comment), force_bytes("The slots attached to this schedule are for neurosurgery operations at Starfleet HQ only."))
        self.assertEqual(force_bytes(inst.id), force_bytes("exampleloc2"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://example.org/scheduleid"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("usual"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("47"))
        self.assertEqual(inst.planningHorizon.end.date, FHIRDate("2017-12-25T09:30:00Z").date)
        self.assertEqual(inst.planningHorizon.end.as_json(), "2017-12-25T09:30:00Z")
        self.assertEqual(inst.planningHorizon.start.date, FHIRDate("2017-12-25T09:15:00Z").date)
        self.assertEqual(inst.planningHorizon.start.as_json(), "2017-12-25T09:15:00Z")
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].code), force_bytes("31"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].display), force_bytes("Specialist Surgical"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].code), force_bytes("221"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].display), force_bytes("Surgery - General"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].code), force_bytes("394610002"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].display), force_bytes("Surgery-Neurosurgery"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testSchedule3(self):
        inst = self.instantiate_from("schedule-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Schedule instance")
        self.implSchedule3(inst)
        
        js = inst.as_json()
        self.assertEqual("Schedule", js["resourceType"])
        inst2 = schedule.Schedule(js)
        self.implSchedule3(inst2)
    
    def implSchedule3(self, inst):
        self.assertTrue(inst.active)
        self.assertEqual(force_bytes(inst.comment), force_bytes("The slots attached to this schedule should be specialized to cover immunizations within the clinic"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://example.org/scheduleid"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("usual"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("45"))
        self.assertEqual(inst.planningHorizon.end.date, FHIRDate("2013-12-25T09:30:00Z").date)
        self.assertEqual(inst.planningHorizon.end.as_json(), "2013-12-25T09:30:00Z")
        self.assertEqual(inst.planningHorizon.start.date, FHIRDate("2013-12-25T09:15:00Z").date)
        self.assertEqual(inst.planningHorizon.start.as_json(), "2013-12-25T09:15:00Z")
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].code), force_bytes("17"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].display), force_bytes("General Practice"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].code), force_bytes("57"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].display), force_bytes("Immunization"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].code), force_bytes("408480009"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].display), force_bytes("Clinical immunology"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/PaymentNotice) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class PaymentNotice(domainresource.DomainResource):
    """ PaymentNotice request.
    
    This resource provides the status of the payment for goods and services
    rendered, and the request and response resource references.
    """
    
    resource_type = "PaymentNotice"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.created = None
        """ Creation date.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.identifier = None
        """ Business Identifier.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.organization = None
        """ Responsible organization.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        self.paymentStatus = None
        """ Whether payment has been sent or cleared.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.provider = None
        """ Responsible practitioner.
        Type `FHIRReference` referencing `Practitioner` (represented as `dict` in JSON). """
        
        self.request = None
        """ Request reference.
        Type `FHIRReference` referencing `Resource` (represented as `dict` in JSON). """
        
        self.response = None
        """ Response reference.
        Type `FHIRReference` referencing `Resource` (represented as `dict` in JSON). """
        
        self.status = None
        """ active | cancelled | draft | entered-in-error.
        Type `str`. """
        
        self.statusDate = None
        """ Payment or clearing date.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.target = None
        """ Insurer or Regulatory body.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        super(PaymentNotice, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(PaymentNotice, self).elementProperties()
        js.extend([
            ("created", "created", fhirdate.FHIRDate, False, None, False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("organization", "organization", fhirreference.FHIRReference, False, None, False),
            ("paymentStatus", "paymentStatus", codeableconcept.CodeableConcept, False, None, False),
            ("provider", "provider", fhirreference.FHIRReference, False, None, False),
            ("request", "request", fhirreference.FHIRReference, False, None, False),
            ("response", "response", fhirreference.FHIRReference, False, None, False),
            ("status", "status", str, False, None, False),
            ("statusDate", "statusDate", fhirdate.FHIRDate, False, None, False),
            ("target", "target", fhirreference.FHIRReference, False, None, False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import measure
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class MeasureTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Measure", js["resourceType"])
        return measure.Measure(js)
    
    def testMeasure1(self):
        inst = self.instantiate_from("measure-composite-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Measure instance")
        self.implMeasure1(inst)
        
        js = inst.as_json()
        self.assertEqual("Measure", js["resourceType"])
        inst2 = measure.Measure(js)
        self.implMeasure1(inst2)
    
    def implMeasure1(self, inst):
        self.assertEqual(force_bytes(inst.compositeScoring.coding[0].code), force_bytes("opportunity"))
        self.assertEqual(force_bytes(inst.id), force_bytes("composite-example"))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].type), force_bytes("composed-of"))
        self.assertEqual(force_bytes(inst.relatedArtifact[1].type), force_bytes("composed-of"))
        self.assertEqual(force_bytes(inst.scoring.coding[0].code), force_bytes("proportion"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Behavioral Assessment Composite Measure"))
    
    def testMeasure2(self):
        inst = self.instantiate_from("measure-component-b-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Measure instance")
        self.implMeasure2(inst)
        
        js = inst.as_json()
        self.assertEqual("Measure", js["resourceType"])
        inst2 = measure.Measure(js)
        self.implMeasure2(inst2)
    
    def implMeasure2(self, inst):
        self.assertEqual(force_bytes(inst.group[0].identifier.value), force_bytes("Main"))
        self.assertEqual(force_bytes(inst.group[0].population[0].code.coding[0].code), force_bytes("initial-population"))
        self.assertEqual(force_bytes(inst.group[0].population[0].criteria), force_bytes("Initial Population"))
        self.assertEqual(force_bytes(inst.group[0].population[1].code.coding[0].code), force_bytes("denominator"))
        self.assertEqual(force_bytes(inst.group[0].population[1].criteria), force_bytes("Denominator"))
        self.assertEqual(force_bytes(inst.group[0].population[2].code.coding[0].code), force_bytes("numerator"))
        self.assertEqual(force_bytes(inst.group[0].population[2].criteria), force_bytes("Numerator"))
        self.assertEqual(force_bytes(inst.id), force_bytes("component-b-example"))
        self.assertEqual(force_bytes(inst.scoring.coding[0].code), force_bytes("proportion"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Screening for Depression"))
    
    def testMeasure3(self):
        inst = self.instantiate_from("measure-predecessor-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Measure instance")
        self.implMeasure3(inst)
        
        js = inst.as_json()
        self.assertEqual("Measure", js["resourceType"])
        inst2 = measure.Measure(js)
        self.implMeasure3(inst2)
    
    def implMeasure3(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2014-03-08").date)
        self.assertEqual(inst.date.as_json(), "2014-03-08")
        self.assertEqual(force_bytes(inst.description), force_bytes("Exclusive breastfeeding measure of outcomes for exclusive breastmilk feeding of newborns."))
        self.assertEqual(force_bytes(inst.group[0].identifier.value), force_bytes("Population Group 1"))
        self.assertEqual(force_bytes(inst.group[0].population[0].code.coding[0].code), force_bytes("initial-population"))
        self.assertEqual(force_bytes(inst.group[0].population[0].criteria), force_bytes("InitialPopulation1"))
        self.assertEqual(force_bytes(inst.group[0].population[0].identifier.value), force_bytes("initial-population-1-identifier"))
        self.assertEqual(force_bytes(inst.group[0].population[1].code.coding[0].code), force_bytes("denominator"))
        self.assertEqual(force_bytes(inst.group[0].population[1].criteria), force_bytes("Denominator1"))
        self.assertEqual(force_bytes(inst.group[0].population[1].identifier.value), force_bytes("denominator-1-identifier"))
        self.assertEqual(force_bytes(inst.group[0].population[2].code.coding[0].code), force_bytes("denominator-exclusions"))
        self.assertEqual(force_bytes(inst.group[0].population[2].criteria), force_bytes("DenominatorExclusions1"))
        self.assertEqual(force_bytes(inst.group[0].population[2].identifier.value), force_bytes("denominator-exclusions-1-identifier"))
        self.assertEqual(force_bytes(inst.group[0].population[3].code.coding[0].code), force_bytes("numerator"))
        self.assertEqual(force_bytes(inst.group[0].population[3].criteria), force_bytes("Numerator1"))
        self.assertEqual(force_bytes(inst.group[0].population[3].identifier.value), force_bytes("numerator-1-identifier"))
        self.assertEqual(force_bytes(inst.group[1].identifier.value), force_bytes("Population Group 2"))
        self.assertEqual(force_bytes(inst.group[1].population[0].code.coding[0].code), force_bytes("initial-population"))
        self.assertEqual(force_bytes(inst.group[1].population[0].criteria), force_bytes("InitialPopulation2"))
        self.assertEqual(force_bytes(inst.group[1].population[0].identifier.value), force_bytes("initial-population-2-identifier"))
        self.assertEqual(force_bytes(inst.group[1].population[1].code.coding[0].code), force_bytes("denominator"))
        self.assertEqual(force_bytes(inst.group[1].population[1].criteria), force_bytes("Denominator2"))
        self.assertEqual(force_bytes(inst.group[1].population[1].identifier.value), force_bytes("denominator-2-identifier"))
        self.assertEqual(force_bytes(inst.group[1].population[2].code.coding[0].code), force_bytes("denominator-exclusion"))
        self.assertEqual(force_bytes(inst.group[1].population[2].criteria), force_bytes("DenominatorExclusions2"))
        self.assertEqual(force_bytes(inst.group[1].population[2].identifier.value), force_bytes("denominator-exclusions-2-identifier"))
        self.assertEqual(force_bytes(inst.group[1].population[3].code.coding[0].code), force_bytes("numerator"))
        self.assertEqual(force_bytes(inst.group[1].population[3].criteria), force_bytes("Numerator2"))
        self.assertEqual(force_bytes(inst.group[1].population[3].identifier.value), force_bytes("numerator-2-identifier"))
        self.assertEqual(force_bytes(inst.id), force_bytes("measure-predecessor-example"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("exclusive-breastfeeding-measure"))
        self.assertEqual(force_bytes(inst.improvementNotation), force_bytes("Improvement noted as an increase in the rate"))
        self.assertEqual(force_bytes(inst.purpose), force_bytes("Measure of newborns who were fed breast milk only since birth"))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].citation), force_bytes("American Academy of Pediatrics. (2005). Section on Breastfeeding. Policy Statement:Breastfeeding and the Use of Human Milk. Pediatrics.115:496-506."))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[1].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[2].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[3].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[4].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[5].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[6].citation), force_bytes("Kramer, M.S. & Kakuma, R. (2002).Optimal duration of exclusive breastfeeding. [107 refs] Cochrane Database of Systematic Reviews. (1):CD003517."))
        self.assertEqual(force_bytes(inst.relatedArtifact[6].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[7].citation), force_bytes("Petrova, A., Hegyi, T., & Mehta, R. (2007). Maternal race/ethnicity and one-month exclusive breastfeeding in association with the in-hospital feeding modality. Breastfeeding Medicine. 2(2):92-8."))
        self.assertEqual(force_bytes(inst.relatedArtifact[7].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[8].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[9].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.scoring.coding[0].code), force_bytes("proportion"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Exclusive Breastfeeding Measure"))
        self.assertEqual(force_bytes(inst.topic[0].text), force_bytes("Exclusive Breastfeeding"))
        self.assertEqual(force_bytes(inst.type[0].coding[0].code), force_bytes("process"))
        self.assertEqual(force_bytes(inst.version), force_bytes("3.0.1"))
    
    def testMeasure4(self):
        inst = self.instantiate_from("measure-cms146-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Measure instance")
        self.implMeasure4(inst)
        
        js = inst.as_json()
        self.assertEqual("Measure", js["resourceType"])
        inst2 = measure.Measure(js)
        self.implMeasure4(inst2)
    
    def implMeasure4(self, inst):
        self.assertEqual(inst.approvalDate.date, FHIRDate("2016-01-01").date)
        self.assertEqual(inst.approvalDate.as_json(), "2016-01-01")
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("url"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("http://www.ncqa.org/"))
        self.assertEqual(force_bytes(inst.contributor[0].name), force_bytes("National Committee for Quality Assurance"))
        self.assertEqual(force_bytes(inst.contributor[0].type), force_bytes("author"))
        self.assertEqual(inst.date.date, FHIRDate("2017-03-10").date)
        self.assertEqual(inst.date.as_json(), "2017-03-10")
        self.assertEqual(force_bytes(inst.description), force_bytes("Percentage of children 3-18 years of age who were diagnosed with pharyngitis, ordered an antibiotic and received a group A streptococcus (strep) test for the episode."))
        self.assertEqual(inst.effectivePeriod.end.date, FHIRDate("2017-12-31").date)
        self.assertEqual(inst.effectivePeriod.end.as_json(), "2017-12-31")
        self.assertEqual(inst.effectivePeriod.start.date, FHIRDate("2017-01-01").date)
        self.assertEqual(inst.effectivePeriod.start.as_json(), "2017-01-01")
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.group[0].identifier.value), force_bytes("CMS146-group-1"))
        self.assertEqual(force_bytes(inst.group[0].population[0].code.coding[0].code), force_bytes("initial-population"))
        self.assertEqual(force_bytes(inst.group[0].population[0].criteria), force_bytes("CMS146.InInitialPopulation"))
        self.assertEqual(force_bytes(inst.group[0].population[0].identifier.value), force_bytes("initial-population-identifier"))
        self.assertEqual(force_bytes(inst.group[0].population[1].code.coding[0].code), force_bytes("numerator"))
        self.assertEqual(force_bytes(inst.group[0].population[1].criteria), force_bytes("CMS146.InNumerator"))
        self.assertEqual(force_bytes(inst.group[0].population[1].identifier.value), force_bytes("numerator-identifier"))
        self.assertEqual(force_bytes(inst.group[0].population[2].code.coding[0].code), force_bytes("denominator"))
        self.assertEqual(force_bytes(inst.group[0].population[2].criteria), force_bytes("CMS146.InDenominator"))
        self.assertEqual(force_bytes(inst.group[0].population[2].identifier.value), force_bytes("denominator-identifier"))
        self.assertEqual(force_bytes(inst.group[0].population[3].code.coding[0].code), force_bytes("denominator-exclusion"))
        self.assertEqual(force_bytes(inst.group[0].population[3].criteria), force_bytes("CMS146.InDenominatorExclusions"))
        self.assertEqual(force_bytes(inst.group[0].population[3].identifier.value), force_bytes("denominator-exclusions-identifier"))
        self.assertEqual(force_bytes(inst.group[0].stratifier[0].criteria), force_bytes("CMS146.AgesUpToNine"))
        self.assertEqual(force_bytes(inst.group[0].stratifier[0].identifier.value), force_bytes("stratifier-ages-up-to-9"))
        self.assertEqual(force_bytes(inst.group[0].stratifier[1].criteria), force_bytes("CMS146.AgesTenPlus"))
        self.assertEqual(force_bytes(inst.group[0].stratifier[1].identifier.value), force_bytes("stratifier-ages-10-plus"))
        self.assertEqual(force_bytes(inst.group[0].stratifier[2].identifier.value), force_bytes("stratifier-ages-up-to-9"))
        self.assertEqual(force_bytes(inst.group[0].stratifier[2].path), force_bytes("Patient.gender"))
        self.assertEqual(force_bytes(inst.guidance), force_bytes("This is an episode of care measure that examines all eligible episodes for the patient during the measurement period. If the patient has more than one episode, include all episodes in the measure"))
        self.assertEqual(force_bytes(inst.id), force_bytes("measure-cms146-example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://hl7.org/fhir/cqi/ecqm/Measure/Identifier/cms"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("146"))
        self.assertEqual(force_bytes(inst.identifier[1].system), force_bytes("http://hl7.org/fhir/cqi/ecqm/Measure/Identifier/nqf"))
        self.assertEqual(force_bytes(inst.identifier[1].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[1].value), force_bytes("0002"))
        self.assertEqual(force_bytes(inst.improvementNotation), force_bytes("Higher score indicates better quality"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].code), force_bytes("US"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].system), force_bytes("urn:iso:std:iso:3166"))
        self.assertEqual(inst.lastReviewDate.date, FHIRDate("2016-09-01").date)
        self.assertEqual(inst.lastReviewDate.as_json(), "2016-09-01")
        self.assertEqual(force_bytes(inst.name), force_bytes("CMS146"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("National Committee for Quality Assurance"))
        self.assertEqual(force_bytes(inst.purpose), force_bytes("Measure of children with a group A streptococcus test in the 7-day period from 3 days prior through 3 days after the diagnosis of pharyngitis"))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].citation), force_bytes("Linder, J.A., D.W. Bates, G.M. Lee, J.A. Finkelstein. 2005. \"Antibiotic treatment of children with sore throat.\" JAMA 294(18):2315-2322. "))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[1].citation), force_bytes("Infectious Diseases Society of America. 2012. \"Clinical Practice Guideline for the Diagnosis and Management of Group A Streptococcal Pharyngitis: 2012 Update.\" "))
        self.assertEqual(force_bytes(inst.relatedArtifact[1].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.relatedArtifact[2].type), force_bytes("documentation"))
        self.assertEqual(force_bytes(inst.scoring.coding[0].code), force_bytes("proportion"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.supplementalData[0].identifier.value), force_bytes("supplemental-data-gender"))
        self.assertEqual(force_bytes(inst.supplementalData[0].path), force_bytes("Patient.gender"))
        self.assertEqual(force_bytes(inst.supplementalData[1].identifier.value), force_bytes("supplemental-data-deceased"))
        self.assertEqual(force_bytes(inst.supplementalData[1].path), force_bytes("deceasedBoolean"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Appropriate Testing for Children with Pharyngitis"))
        self.assertEqual(force_bytes(inst.topic[0].coding[0].code), force_bytes("57024-2"))
        self.assertEqual(force_bytes(inst.topic[0].coding[0].system), force_bytes("http://hl7.org/fhir/c80-doc-typecodes"))
        self.assertEqual(force_bytes(inst.type[0].coding[0].code), force_bytes("process"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/Measure/measure-cms146-example"))
        self.assertEqual(force_bytes(inst.useContext[0].code.code), force_bytes("program"))
        self.assertEqual(force_bytes(inst.useContext[0].valueCodeableConcept.text), force_bytes("eligibile-provider"))
        self.assertEqual(force_bytes(inst.version), force_bytes("1.0.0"))
    
    def testMeasure5(self):
        inst = self.instantiate_from("measure-component-a-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Measure instance")
        self.implMeasure5(inst)
        
        js = inst.as_json()
        self.assertEqual("Measure", js["resourceType"])
        inst2 = measure.Measure(js)
        self.implMeasure5(inst2)
    
    def implMeasure5(self, inst):
        self.assertEqual(force_bytes(inst.group[0].identifier.value), force_bytes("Main"))
        self.assertEqual(force_bytes(inst.group[0].population[0].code.coding[0].code), force_bytes("initial-population"))
        self.assertEqual(force_bytes(inst.group[0].population[0].criteria), force_bytes("Initial Population"))
        self.assertEqual(force_bytes(inst.group[0].population[1].code.coding[0].code), force_bytes("denominator"))
        self.assertEqual(force_bytes(inst.group[0].population[1].criteria), force_bytes("Denominator"))
        self.assertEqual(force_bytes(inst.group[0].population[2].code.coding[0].code), force_bytes("numerator"))
        self.assertEqual(force_bytes(inst.group[0].population[2].criteria), force_bytes("Numerator"))
        self.assertEqual(force_bytes(inst.id), force_bytes("component-a-example"))
        self.assertEqual(force_bytes(inst.scoring.coding[0].code), force_bytes("proportion"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Screening for Alcohol Misuse"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/MedicationDispense) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class MedicationDispense(domainresource.DomainResource):
    """ Dispensing a medication to a named patient.
    
    Indicates that a medication product is to be or has been dispensed for a
    named person/patient.  This includes a description of the medication
    product (supply) provided and the instructions for administering the
    medication.  The medication dispense is the result of a pharmacy system
    responding to a medication order.
    """
    
    resource_type = "MedicationDispense"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.authorizingPrescription = None
        """ Medication order that authorizes the dispense.
        List of `FHIRReference` items referencing `MedicationRequest` (represented as `dict` in JSON). """
        
        self.category = None
        """ Type of medication dispense.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.context = None
        """ Encounter / Episode associated with event.
        Type `FHIRReference` referencing `Encounter, EpisodeOfCare` (represented as `dict` in JSON). """
        
        self.daysSupply = None
        """ Amount of medication expressed as a timing amount.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.destination = None
        """ Where the medication was sent.
        Type `FHIRReference` referencing `Location` (represented as `dict` in JSON). """
        
        self.detectedIssue = None
        """ Clinical issue with action.
        List of `FHIRReference` items referencing `DetectedIssue` (represented as `dict` in JSON). """
        
        self.dosageInstruction = None
        """ How the medication is to be used by the patient or administered by
        the caregiver.
        List of `Dosage` items (represented as `dict` in JSON). """
        
        self.eventHistory = None
        """ A list of releveant lifecycle events.
        List of `FHIRReference` items referencing `Provenance` (represented as `dict` in JSON). """
        
        self.identifier = None
        """ External identifier.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.medicationCodeableConcept = None
        """ What medication was supplied.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.medicationReference = None
        """ What medication was supplied.
        Type `FHIRReference` referencing `Medication` (represented as `dict` in JSON). """
        
        self.notDone = None
        """ Whether the dispense was or was not performed.
        Type `bool`. """
        
        self.notDoneReasonCodeableConcept = None
        """ Why a dispense was not performed.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.notDoneReasonReference = None
        """ Why a dispense was not performed.
        Type `FHIRReference` referencing `DetectedIssue` (represented as `dict` in JSON). """
        
        self.note = None
        """ Information about the dispense.
        List of `Annotation` items (represented as `dict` in JSON). """
        
        self.partOf = None
        """ Event that dispense is part of.
        List of `FHIRReference` items referencing `Procedure` (represented as `dict` in JSON). """
        
        self.performer = None
        """ Who performed event.
        List of `MedicationDispensePerformer` items (represented as `dict` in JSON). """
        
        self.quantity = None
        """ Amount dispensed.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.receiver = None
        """ Who collected the medication.
        List of `FHIRReference` items referencing `Patient, Practitioner` (represented as `dict` in JSON). """
        
        self.status = None
        """ preparation | in-progress | on-hold | completed | entered-in-error
        | stopped.
        Type `str`. """
        
        self.subject = None
        """ Who the dispense is for.
        Type `FHIRReference` referencing `Patient, Group` (represented as `dict` in JSON). """
        
        self.substitution = None
        """ Whether a substitution was performed on the dispense.
        Type `MedicationDispenseSubstitution` (represented as `dict` in JSON). """
        
        self.supportingInformation = None
        """ Information that supports the dispensing of the medication.
        List of `FHIRReference` items referencing `Resource` (represented as `dict` in JSON). """
        
        self.type = None
        """ Trial fill, partial fill, emergency fill, etc..
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.whenHandedOver = None
        """ When product was given out.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.whenPrepared = None
        """ When product was packaged and reviewed.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        super(MedicationDispense, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(MedicationDispense, self).elementProperties()
        js.extend([
            ("authorizingPrescription", "authorizingPrescription", fhirreference.FHIRReference, True, None, False),
            ("category", "category", codeableconcept.CodeableConcept, False, None, False),
            ("context", "context", fhirreference.FHIRReference, False, None, False),
            ("daysSupply", "daysSupply", quantity.Quantity, False, None, False),
            ("destination", "destination", fhirreference.FHIRReference, False, None, False),
            ("detectedIssue", "detectedIssue", fhirreference.FHIRReference, True, None, False),
            ("dosageInstruction", "dosageInstruction", dosage.Dosage, True, None, False),
            ("eventHistory", "eventHistory", fhirreference.FHIRReference, True, None, False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("medicationCodeableConcept", "medicationCodeableConcept", codeableconcept.CodeableConcept, False, "medication", True),
            ("medicationReference", "medicationReference", fhirreference.FHIRReference, False, "medication", True),
            ("notDone", "notDone", bool, False, None, False),
            ("notDoneReasonCodeableConcept", "notDoneReasonCodeableConcept", codeableconcept.CodeableConcept, False, "notDoneReason", False),
            ("notDoneReasonReference", "notDoneReasonReference", fhirreference.FHIRReference, False, "notDoneReason", False),
            ("note", "note", annotation.Annotation, True, None, False),
            ("partOf", "partOf", fhirreference.FHIRReference, True, None, False),
            ("performer", "performer", MedicationDispensePerformer, True, None, False),
            ("quantity", "quantity", quantity.Quantity, False, None, False),
            ("receiver", "receiver", fhirreference.FHIRReference, True, None, False),
            ("status", "status", str, False, None, False),
            ("subject", "subject", fhirreference.FHIRReference, False, None, False),
            ("substitution", "substitution", MedicationDispenseSubstitution, False, None, False),
            ("supportingInformation", "supportingInformation", fhirreference.FHIRReference, True, None, False),
            ("type", "type", codeableconcept.CodeableConcept, False, None, False),
            ("whenHandedOver", "whenHandedOver", fhirdate.FHIRDate, False, None, False),
            ("whenPrepared", "whenPrepared", fhirdate.FHIRDate, False, None, False),
        ])
        return js


from . import backboneelement

class MedicationDispensePerformer(backboneelement.BackboneElement):
    """ Who performed event.
    
    Indicates who or what performed the event.  It should be assumed that the
    performer is the dispenser of the medication.
    """
    
    resource_type = "MedicationDispensePerformer"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.actor = None
        """ Individual who was performing.
        Type `FHIRReference` referencing `Practitioner, Organization, Patient, Device, RelatedPerson` (represented as `dict` in JSON). """
        
        self.onBehalfOf = None
        """ Organization organization was acting for.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        super(MedicationDispensePerformer, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(MedicationDispensePerformer, self).elementProperties()
        js.extend([
            ("actor", "actor", fhirreference.FHIRReference, False, None, True),
            ("onBehalfOf", "onBehalfOf", fhirreference.FHIRReference, False, None, False),
        ])
        return js


class MedicationDispenseSubstitution(backboneelement.BackboneElement):
    """ Whether a substitution was performed on the dispense.
    
    Indicates whether or not substitution was made as part of the dispense.  In
    some cases substitution will be expected but does not happen, in other
    cases substitution is not expected but does happen.  This block explains
    what substitution did or did not happen and why.  If nothing is specified,
    substitution was not done.
    """
    
    resource_type = "MedicationDispenseSubstitution"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.reason = None
        """ Why was substitution made.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.responsibleParty = None
        """ Who is responsible for the substitution.
        List of `FHIRReference` items referencing `Practitioner` (represented as `dict` in JSON). """
        
        self.type = None
        """ Code signifying whether a different drug was dispensed from what
        was prescribed.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.wasSubstituted = None
        """ Whether a substitution was or was not performed on the dispense.
        Type `bool`. """
        
        super(MedicationDispenseSubstitution, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(MedicationDispenseSubstitution, self).elementProperties()
        js.extend([
            ("reason", "reason", codeableconcept.CodeableConcept, True, None, False),
            ("responsibleParty", "responsibleParty", fhirreference.FHIRReference, True, None, False),
            ("type", "type", codeableconcept.CodeableConcept, False, None, False),
            ("wasSubstituted", "wasSubstituted", bool, False, None, True),
        ])
        return js


import sys
try:
    from . import annotation
except ImportError:
    annotation = sys.modules[__package__ + '.annotation']
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import dosage
except ImportError:
    dosage = sys.modules[__package__ + '.dosage']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import quantity
except ImportError:
    quantity = sys.modules[__package__ + '.quantity']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/ClinicalImpression) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class ClinicalImpression(domainresource.DomainResource):
    """ A clinical assessment performed when planning treatments and management
    strategies for a patient.
    
    A record of a clinical assessment performed to determine what problem(s)
    may affect the patient and before planning the treatments or management
    strategies that are best to manage a patient's condition. Assessments are
    often 1:1 with a clinical consultation / encounter,  but this varies
    greatly depending on the clinical workflow. This resource is called
    "ClinicalImpression" rather than "ClinicalAssessment" to avoid confusion
    with the recording of assessment tools such as Apgar score.
    """
    
    resource_type = "ClinicalImpression"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.action = None
        """ Action taken as part of assessment procedure.
        List of `FHIRReference` items referencing `ReferralRequest, ProcedureRequest, Procedure, MedicationRequest, Appointment` (represented as `dict` in JSON). """
        
        self.assessor = None
        """ The clinician performing the assessment.
        Type `FHIRReference` referencing `Practitioner` (represented as `dict` in JSON). """
        
        self.code = None
        """ Kind of assessment performed.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.context = None
        """ Encounter or Episode created from.
        Type `FHIRReference` referencing `Encounter, EpisodeOfCare` (represented as `dict` in JSON). """
        
        self.date = None
        """ When the assessment was documented.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.description = None
        """ Why/how the assessment was performed.
        Type `str`. """
        
        self.effectiveDateTime = None
        """ Time of assessment.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.effectivePeriod = None
        """ Time of assessment.
        Type `Period` (represented as `dict` in JSON). """
        
        self.finding = None
        """ Possible or likely findings and diagnoses.
        List of `ClinicalImpressionFinding` items (represented as `dict` in JSON). """
        
        self.identifier = None
        """ Business identifier.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.investigation = None
        """ One or more sets of investigations (signs, symptions, etc.).
        List of `ClinicalImpressionInvestigation` items (represented as `dict` in JSON). """
        
        self.note = None
        """ Comments made about the ClinicalImpression.
        List of `Annotation` items (represented as `dict` in JSON). """
        
        self.previous = None
        """ Reference to last assessment.
        Type `FHIRReference` referencing `ClinicalImpression` (represented as `dict` in JSON). """
        
        self.problem = None
        """ Relevant impressions of patient state.
        List of `FHIRReference` items referencing `Condition, AllergyIntolerance` (represented as `dict` in JSON). """
        
        self.prognosisCodeableConcept = None
        """ Estimate of likely outcome.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.prognosisReference = None
        """ RiskAssessment expressing likely outcome.
        List of `FHIRReference` items referencing `RiskAssessment` (represented as `dict` in JSON). """
        
        self.protocol = None
        """ Clinical Protocol followed.
        List of `str` items. """
        
        self.status = None
        """ draft | completed | entered-in-error.
        Type `str`. """
        
        self.subject = None
        """ Patient or group assessed.
        Type `FHIRReference` referencing `Patient, Group` (represented as `dict` in JSON). """
        
        self.summary = None
        """ Summary of the assessment.
        Type `str`. """
        
        super(ClinicalImpression, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ClinicalImpression, self).elementProperties()
        js.extend([
            ("action", "action", fhirreference.FHIRReference, True, None, False),
            ("assessor", "assessor", fhirreference.FHIRReference, False, None, False),
            ("code", "code", codeableconcept.CodeableConcept, False, None, False),
            ("context", "context", fhirreference.FHIRReference, False, None, False),
            ("date", "date", fhirdate.FHIRDate, False, None, False),
            ("description", "description", str, False, None, False),
            ("effectiveDateTime", "effectiveDateTime", fhirdate.FHIRDate, False, "effective", False),
            ("effectivePeriod", "effectivePeriod", period.Period, False, "effective", False),
            ("finding", "finding", ClinicalImpressionFinding, True, None, False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("investigation", "investigation", ClinicalImpressionInvestigation, True, None, False),
            ("note", "note", annotation.Annotation, True, None, False),
            ("previous", "previous", fhirreference.FHIRReference, False, None, False),
            ("problem", "problem", fhirreference.FHIRReference, True, None, False),
            ("prognosisCodeableConcept", "prognosisCodeableConcept", codeableconcept.CodeableConcept, True, None, False),
            ("prognosisReference", "prognosisReference", fhirreference.FHIRReference, True, None, False),
            ("protocol", "protocol", str, True, None, False),
            ("status", "status", str, False, None, True),
            ("subject", "subject", fhirreference.FHIRReference, False, None, True),
            ("summary", "summary", str, False, None, False),
        ])
        return js


from . import backboneelement

class ClinicalImpressionFinding(backboneelement.BackboneElement):
    """ Possible or likely findings and diagnoses.
    
    Specific findings or diagnoses that was considered likely or relevant to
    ongoing treatment.
    """
    
    resource_type = "ClinicalImpressionFinding"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.basis = None
        """ Which investigations support finding.
        Type `str`. """
        
        self.itemCodeableConcept = None
        """ What was found.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.itemReference = None
        """ What was found.
        Type `FHIRReference` referencing `Condition, Observation` (represented as `dict` in JSON). """
        
        super(ClinicalImpressionFinding, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ClinicalImpressionFinding, self).elementProperties()
        js.extend([
            ("basis", "basis", str, False, None, False),
            ("itemCodeableConcept", "itemCodeableConcept", codeableconcept.CodeableConcept, False, "item", True),
            ("itemReference", "itemReference", fhirreference.FHIRReference, False, "item", True),
        ])
        return js


class ClinicalImpressionInvestigation(backboneelement.BackboneElement):
    """ One or more sets of investigations (signs, symptions, etc.).
    
    One or more sets of investigations (signs, symptions, etc.). The actual
    grouping of investigations vary greatly depending on the type and context
    of the assessment. These investigations may include data generated during
    the assessment process, or data previously generated and recorded that is
    pertinent to the outcomes.
    """
    
    resource_type = "ClinicalImpressionInvestigation"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.code = None
        """ A name/code for the set.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.item = None
        """ Record of a specific investigation.
        List of `FHIRReference` items referencing `Observation, QuestionnaireResponse, FamilyMemberHistory, DiagnosticReport, RiskAssessment, ImagingStudy` (represented as `dict` in JSON). """
        
        super(ClinicalImpressionInvestigation, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ClinicalImpressionInvestigation, self).elementProperties()
        js.extend([
            ("code", "code", codeableconcept.CodeableConcept, False, None, True),
            ("item", "item", fhirreference.FHIRReference, True, None, False),
        ])
        return js


import sys
try:
    from . import annotation
except ImportError:
    annotation = sys.modules[__package__ + '.annotation']
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/Dosage) on 2019-01-12.
#  2019, SMART Health IT.


from . import element

class Dosage(element.Element):
    """ How the medication is/was taken or should be taken.
    
    Indicates how the medication is/was taken or should be taken by the
    patient.
    """
    
    resource_type = "Dosage"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.additionalInstruction = None
        """ Supplemental instruction - e.g. "with meals".
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.asNeededBoolean = None
        """ Take "as needed" (for x).
        Type `bool`. """
        
        self.asNeededCodeableConcept = None
        """ Take "as needed" (for x).
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.doseQuantity = None
        """ Amount of medication per dose.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.doseRange = None
        """ Amount of medication per dose.
        Type `Range` (represented as `dict` in JSON). """
        
        self.maxDosePerAdministration = None
        """ Upper limit on medication per administration.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.maxDosePerLifetime = None
        """ Upper limit on medication per lifetime of the patient.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.maxDosePerPeriod = None
        """ Upper limit on medication per unit of time.
        Type `Ratio` (represented as `dict` in JSON). """
        
        self.method = None
        """ Technique for administering medication.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.patientInstruction = None
        """ Patient or consumer oriented instructions.
        Type `str`. """
        
        self.rateQuantity = None
        """ Amount of medication per unit of time.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.rateRange = None
        """ Amount of medication per unit of time.
        Type `Range` (represented as `dict` in JSON). """
        
        self.rateRatio = None
        """ Amount of medication per unit of time.
        Type `Ratio` (represented as `dict` in JSON). """
        
        self.route = None
        """ How drug should enter body.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.sequence = None
        """ The order of the dosage instructions.
        Type `int`. """
        
        self.site = None
        """ Body site to administer to.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.text = None
        """ Free text dosage instructions e.g. SIG.
        Type `str`. """
        
        self.timing = None
        """ When medication should be administered.
        Type `Timing` (represented as `dict` in JSON). """
        
        super(Dosage, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(Dosage, self).elementProperties()
        js.extend([
            ("additionalInstruction", "additionalInstruction", codeableconcept.CodeableConcept, True, None, False),
            ("asNeededBoolean", "asNeededBoolean", bool, False, "asNeeded", False),
            ("asNeededCodeableConcept", "asNeededCodeableConcept", codeableconcept.CodeableConcept, False, "asNeeded", False),
            ("doseQuantity", "doseQuantity", quantity.Quantity, False, "dose", False),
            ("doseRange", "doseRange", range.Range, False, "dose", False),
            ("maxDosePerAdministration", "maxDosePerAdministration", quantity.Quantity, False, None, False),
            ("maxDosePerLifetime", "maxDosePerLifetime", quantity.Quantity, False, None, False),
            ("maxDosePerPeriod", "maxDosePerPeriod", ratio.Ratio, False, None, False),
            ("method", "method", codeableconcept.CodeableConcept, False, None, False),
            ("patientInstruction", "patientInstruction", str, False, None, False),
            ("rateQuantity", "rateQuantity", quantity.Quantity, False, "rate", False),
            ("rateRange", "rateRange", range.Range, False, "rate", False),
            ("rateRatio", "rateRatio", ratio.Ratio, False, "rate", False),
            ("route", "route", codeableconcept.CodeableConcept, False, None, False),
            ("sequence", "sequence", int, False, None, False),
            ("site", "site", codeableconcept.CodeableConcept, False, None, False),
            ("text", "text", str, False, None, False),
            ("timing", "timing", timing.Timing, False, None, False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import quantity
except ImportError:
    quantity = sys.modules[__package__ + '.quantity']
try:
    from . import range
except ImportError:
    range = sys.modules[__package__ + '.range']
try:
    from . import ratio
except ImportError:
    ratio = sys.modules[__package__ + '.ratio']
try:
    from . import timing
except ImportError:
    timing = sys.modules[__package__ + '.timing']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import consent
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class ConsentTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Consent", js["resourceType"])
        return consent.Consent(js)
    
    def testConsent1(self):
        inst = self.instantiate_from("consent-example-Emergency.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent1(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent1(inst2)
    
    def implConsent1(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2015-11-18").date)
        self.assertEqual(inst.dateTime.as_json(), "2015-11-18")
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].code), force_bytes("CST"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[0].purpose[0].code), force_bytes("ETREAT"))
        self.assertEqual(force_bytes(inst.except_fhir[0].purpose[0].system), force_bytes("http://hl7.org/fhir/v3/ActReason"))
        self.assertEqual(force_bytes(inst.except_fhir[0].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[1].actor[0].role.coding[0].code), force_bytes("CST"))
        self.assertEqual(force_bytes(inst.except_fhir[1].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[1].type), force_bytes("deny"))
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-Emergency"))
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-out"))
        self.assertEqual(force_bytes(inst.sourceAttachment.title), force_bytes("The terms of the consent in lawyer speak."))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent2(self):
        inst = self.instantiate_from("consent-example-notThis.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent2(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent2(inst2)
    
    def implConsent2(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2015-11-18").date)
        self.assertEqual(inst.dateTime.as_json(), "2015-11-18")
        self.assertEqual(force_bytes(inst.except_fhir[0].data[0].meaning), force_bytes("related"))
        self.assertEqual(force_bytes(inst.except_fhir[0].type), force_bytes("deny"))
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-notThis"))
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-in"))
        self.assertEqual(force_bytes(inst.sourceAttachment.title), force_bytes("The terms of the consent in lawyer speak."))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent3(self):
        inst = self.instantiate_from("consent-example-pkb.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent3(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent3(inst2)
    
    def implConsent3(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2016-06-16").date)
        self.assertEqual(inst.dateTime.as_json(), "2016-06-16")
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[0].securityLabel[0].code), force_bytes("N"))
        self.assertEqual(force_bytes(inst.except_fhir[0].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/Confidentiality"))
        self.assertEqual(force_bytes(inst.except_fhir[0].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[1].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[1].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[1].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[1].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[1].securityLabel[0].code), force_bytes("PSY"))
        self.assertEqual(force_bytes(inst.except_fhir[1].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
        self.assertEqual(force_bytes(inst.except_fhir[1].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[2].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[2].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[2].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[2].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[2].securityLabel[0].code), force_bytes("SOC"))
        self.assertEqual(force_bytes(inst.except_fhir[2].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
        self.assertEqual(force_bytes(inst.except_fhir[2].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[3].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[3].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[3].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[3].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[3].securityLabel[0].code), force_bytes("N"))
        self.assertEqual(force_bytes(inst.except_fhir[3].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/Confidentiality"))
        self.assertEqual(force_bytes(inst.except_fhir[3].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[4].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[4].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[4].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[4].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[4].securityLabel[0].code), force_bytes("PSY"))
        self.assertEqual(force_bytes(inst.except_fhir[4].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
        self.assertEqual(force_bytes(inst.except_fhir[4].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[5].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[5].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[5].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[5].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[5].securityLabel[0].code), force_bytes("SOC"))
        self.assertEqual(force_bytes(inst.except_fhir[5].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
        self.assertEqual(force_bytes(inst.except_fhir[5].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[6].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[6].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[6].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[6].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[6].securityLabel[0].code), force_bytes("SEX"))
        self.assertEqual(force_bytes(inst.except_fhir[6].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
        self.assertEqual(force_bytes(inst.except_fhir[6].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[7].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[7].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[7].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[7].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[7].securityLabel[0].code), force_bytes("N"))
        self.assertEqual(force_bytes(inst.except_fhir[7].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/Confidentiality"))
        self.assertEqual(force_bytes(inst.except_fhir[7].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[8].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[8].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[8].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[8].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[8].securityLabel[0].code), force_bytes("PSY"))
        self.assertEqual(force_bytes(inst.except_fhir[8].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
        self.assertEqual(force_bytes(inst.except_fhir[8].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.except_fhir[9].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[9].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[9].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[9].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[9].securityLabel[0].code), force_bytes("SOC"))
        self.assertEqual(force_bytes(inst.except_fhir[9].securityLabel[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
        self.assertEqual(force_bytes(inst.except_fhir[9].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-pkb"))
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-out"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent4(self):
        inst = self.instantiate_from("consent-example-notThem.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent4(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent4(inst2)
    
    def implConsent4(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2015-11-18").date)
        self.assertEqual(inst.dateTime.as_json(), "2015-11-18")
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[1].coding[0].code), force_bytes("correct"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[1].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[0].type), force_bytes("deny"))
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-notThem"))
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-in"))
        self.assertEqual(force_bytes(inst.sourceAttachment.title), force_bytes("The terms of the consent in lawyer speak."))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent5(self):
        inst = self.instantiate_from("consent-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent5(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent5(inst2)
    
    def implConsent5(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2016-05-11").date)
        self.assertEqual(inst.dateTime.as_json(), "2016-05-11")
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-basic"))
        self.assertEqual(inst.period.end.date, FHIRDate("2016-01-01").date)
        self.assertEqual(inst.period.end.as_json(), "2016-01-01")
        self.assertEqual(inst.period.start.date, FHIRDate("1964-01-01").date)
        self.assertEqual(inst.period.start.as_json(), "1964-01-01")
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://goodhealth.org/consent/policy/opt-in"))
        self.assertEqual(force_bytes(inst.sourceAttachment.title), force_bytes("The terms of the consent in lawyer speak."))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent6(self):
        inst = self.instantiate_from("consent-example-Out.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent6(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent6(inst2)
    
    def implConsent6(self, inst):
        self.assertEqual(force_bytes(inst.actor[0].role.coding[0].code), force_bytes("CST"))
        self.assertEqual(force_bytes(inst.actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(inst.dateTime.date, FHIRDate("2015-11-18").date)
        self.assertEqual(inst.dateTime.as_json(), "2015-11-18")
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-Out"))
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-out"))
        self.assertEqual(force_bytes(inst.sourceAttachment.title), force_bytes("The terms of the consent in lawyer speak."))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent7(self):
        inst = self.instantiate_from("consent-example-notOrg.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent7(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent7(inst2)
    
    def implConsent7(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2015-11-18").date)
        self.assertEqual(inst.dateTime.as_json(), "2015-11-18")
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[1].coding[0].code), force_bytes("correct"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[1].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[0].type), force_bytes("deny"))
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-notOrg"))
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-in"))
        self.assertEqual(force_bytes(inst.sourceAttachment.title), force_bytes("The terms of the consent in lawyer speak."))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent8(self):
        inst = self.instantiate_from("consent-example-notTime.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent8(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent8(inst2)
    
    def implConsent8(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2015-11-18").date)
        self.assertEqual(inst.dateTime.as_json(), "2015-11-18")
        self.assertEqual(inst.except_fhir[0].period.end.date, FHIRDate("2015-02-01").date)
        self.assertEqual(inst.except_fhir[0].period.end.as_json(), "2015-02-01")
        self.assertEqual(inst.except_fhir[0].period.start.date, FHIRDate("2015-01-01").date)
        self.assertEqual(inst.except_fhir[0].period.start.as_json(), "2015-01-01")
        self.assertEqual(force_bytes(inst.except_fhir[0].type), force_bytes("deny"))
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-notTime"))
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-in"))
        self.assertEqual(force_bytes(inst.sourceAttachment.title), force_bytes("The terms of the consent in lawyer speak."))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent9(self):
        inst = self.instantiate_from("consent-example-grantor.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent9(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent9(inst2)
    
    def implConsent9(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2015-11-18").date)
        self.assertEqual(inst.dateTime.as_json(), "2015-11-18")
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].code), force_bytes("CST"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[1].role.coding[0].code), force_bytes("PRCP"))
        self.assertEqual(force_bytes(inst.except_fhir[0].actor[1].role.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.except_fhir[0].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-grantor"))
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-out"))
        self.assertEqual(force_bytes(inst.sourceAttachment.title), force_bytes("The terms of the consent in lawyer speak."))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testConsent10(self):
        inst = self.instantiate_from("consent-example-smartonfhir.json")
        self.assertIsNotNone(inst, "Must have instantiated a Consent instance")
        self.implConsent10(inst)
        
        js = inst.as_json()
        self.assertEqual("Consent", js["resourceType"])
        inst2 = consent.Consent(js)
        self.implConsent10(inst2)
    
    def implConsent10(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2016-06-23T17:02:33+10:00").date)
        self.assertEqual(inst.dateTime.as_json(), "2016-06-23T17:02:33+10:00")
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].code), force_bytes("access"))
        self.assertEqual(force_bytes(inst.except_fhir[0].action[0].coding[0].system), force_bytes("http://hl7.org/fhir/consentaction"))
        self.assertEqual(force_bytes(inst.except_fhir[0].class_fhir[0].code), force_bytes("MedicationRequest"))
        self.assertEqual(force_bytes(inst.except_fhir[0].class_fhir[0].system), force_bytes("http://hl7.org/fhir/resource-types"))
        self.assertEqual(force_bytes(inst.except_fhir[0].type), force_bytes("permit"))
        self.assertEqual(force_bytes(inst.id), force_bytes("consent-example-smartonfhir"))
        self.assertEqual(inst.period.end.date, FHIRDate("2016-06-23T17:32:33+10:00").date)
        self.assertEqual(inst.period.end.as_json(), "2016-06-23T17:32:33+10:00")
        self.assertEqual(inst.period.start.date, FHIRDate("2016-06-23T17:02:33+10:00").date)
        self.assertEqual(inst.period.start.as_json(), "2016-06-23T17:02:33+10:00")
        self.assertEqual(force_bytes(inst.policyRule), force_bytes("http://hl7.org/fhir/ConsentPolicy/opt-in"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))

